@@ -4,8 +4,8 @@
 #' @return the line number's index (which is 1 for the first line) if the
 #'   opening tag is found, else NA
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
-find_first_xml_opening_tag_line <- function( # nolint beautier functions may be long
+#' @export
+find_first_xml_opening_tag_line <- function( # nolint indeed long function name
   lines,
   section
 ) {
