@@ -1,15 +1,16 @@
 #' Determine if x is an initialized parameter,
-#'   as created by \code{\link{create_param}}
+#'   as created by \link{create_param}
 #' @param x the object to check if it is an
 #'   initialized parameter
-#' @return TRUE if x is an initialized parameter, FALSE otherwise
+#' @return \link{TRUE} if x is an initialized parameter,
+#' \link{FALSE} otherwise
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_param <- function(
   x
 ) {
-  if (!is_param(x)) { # nolint beautier function
+  if (!beautier::is_param(x)) {
     stop("'x' must be a parameter")
   }
-  !is_one_na(x$id) # nolint beautier function
+  !beautier::is_one_na(x$id)
 }
